@@ -64,7 +64,10 @@ ICON_SIZE = 16
 #Maximum number of history items
 MAX_HISTORY = 25
 HISTORY_FILE = join(USER_DESKBAR_DIR, "history.pickle")
-		
+
+# FIXME: this , here ?
+MAX_RESULTS_PER_HANDLER = 6
+
 #Gconf client
 GCONF_CLIENT = gconf.client_get_default()
 
@@ -79,12 +82,24 @@ GCONF_EXPAND = GCONF_DIR + "/expand"
 # GConf key for global keybinding
 GCONF_KEYBINDING = GCONF_DIR + "/keybinding"
 
+# GConf key for UI name
+GCONF_UI_NAME = GCONF_DIR + "/ui_name"
+
+COMPLETION_UI_NAME = "Completion"
+CUEMIAC_UI_NAME = "Cuemiac"
+
 # GConf key for list of enabled handlers, when uninstalled, use a debug key to not conflict
 # with development version
 if UNINSTALLED_DESKBAR:
 	GCONF_ENABLED_HANDLERS = GCONF_DIR + "/enabled_handlers_debug"
 else:
 	GCONF_ENABLED_HANDLERS = GCONF_DIR + "/enabled_handlers"
-	
+
+# GConf key for collapsed categories in the cuemiac view
+GCONF_COLLAPSED_CAT = GCONF_DIR + "/collapsed_cat"
+
 # Preload gconf directories
 GCONF_CLIENT.add_dir(GCONF_DIR, gconf.CLIENT_PRELOAD_RECURSIVE)
+
+# Global overrides for command line mode
+UI_OVERRIDE = None
